# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2018-06-11 12:20
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('reviews', '0009_auto_20180611_1145'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='review',
            options={'ordering': ('-display_date',)},
        ),
        migrations.AddField(
            model_name='review',
            name='source',
            field=models.TextField(default='', verbose_name='Source'),
        ),
        migrations.AlterField(
            model_name='review',
            name='highlight',
            field=models.BooleanField(default=False, verbose_name='highlight'),
        ),
        migrations.AlterField(
            model_name='review',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='review_comments', to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
    ]
