# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-12 14:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reviews', '0002_auto_20170912_1154'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='review',
            name='ip_address',
        ),
    ]
